---
title: <span class="badge object-type-enum"></span> PieChartLegendValues
---
# <span class="badge object-type-enum"></span> PieChartLegendValues

Select values to display in the legend.

 - Percent: The percentage of the whole.

 - Value: The raw numerical value.

## Definition

```python
class PieChartLegendValues(enum.StrEnum):
    """
    Select values to display in the legend.
     - Percent: The percentage of the whole.
     - Value: The raw numerical value.
    """

    VALUE = "value"
    PERCENT = "percent"
```
